==> aws-java-sdk-ec2-1.10.41-sources.jar: com/amazonaws/services/ec2/model/transform/InstanceCapacityStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.ec2.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Instance Capacity StAX Unmarshaller
 */
public class InstanceCapacityStaxUnmarshaller implements Unmarshaller<InstanceCapacity, StaxUnmarshallerContext> {

    public InstanceCapacity unmarshall(StaxUnmarshallerContext context) throws Exception {
        InstanceCapacity instanceCapacity = new InstanceCapacity();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return instanceCapacity;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("instanceType", targetDepth)) {
                    instanceCapacity.setInstanceType(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("availableCapacity", targetDepth)) {
                    instanceCapacity.setAvailableCapacity(IntegerStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("totalCapacity", targetDepth)) {
                    instanceCapacity.setTotalCapacity(IntegerStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return instanceCapacity;
                }
            }
        }
    }

    private static InstanceCapacityStaxUnmarshaller instance;
    public static InstanceCapacityStaxUnmarshaller getInstance() {
        if (instance == null) instance = new InstanceCapacityStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-ec2-1.10.69-sources.jar: com/amazonaws/services/ec2/model/transform/InstanceCapacityStaxUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.ec2.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * InstanceCapacity StAX Unmarshaller
 */
public class InstanceCapacityStaxUnmarshaller implements
        Unmarshaller<InstanceCapacity, StaxUnmarshallerContext> {

    public InstanceCapacity unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        InstanceCapacity instanceCapacity = new InstanceCapacity();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return instanceCapacity;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("instanceType", targetDepth)) {
                    instanceCapacity.setInstanceType(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("availableCapacity", targetDepth)) {
                    instanceCapacity
                            .setAvailableCapacity(IntegerStaxUnmarshaller
                                    .getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("totalCapacity", targetDepth)) {
                    instanceCapacity.setTotalCapacity(IntegerStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return instanceCapacity;
                }
            }
        }
    }

    private static InstanceCapacityStaxUnmarshaller instance;

    public static InstanceCapacityStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new InstanceCapacityStaxUnmarshaller();
        return instance;
    }
}
